@@ -8,6 +8,8 @@ from .structs import (
     GenerateGuessResponse,
     GenerateHintRequest,
     GenerateHintResponse,
+    LoadModelsRequest,
+    LoadModelsResponse,
 )
 
 log = logging.getLogger(__name__)
@@ -28,3 +30,7 @@ class TheSpymasterSolversClient(BaseHttpClient):
     def generate_guess(self, request: GenerateGuessRequest) -> GenerateGuessResponse:
         data = self._post("generate-guess/", data=request.dict())
         return GenerateGuessResponse(**data)
+
+    def load_models(self, request: LoadModelsRequest) -> LoadModelsResponse:
+        data = self._post("load-models/", data=request.dict())
+        return LoadModelsResponse(**data)
